SimliError class

Represent error with associated error code and message

Constructors

SimliError({required String message, String? errorCode})
initialize with message and errorCode

Properties

errorCode ↔ String?
error code of any error
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
error message for the error
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited