SimliException class

Exception for simli class

Implemented types

Constructors

SimliException(String errorCode, String message)
Constructor for creating a SimliException with a specified errorCode and message.

Properties

errorCode → String
Error code associated with this exception.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
Message providing details about the exception.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited